==> haskell-lifted-base-0.2.3.12-16-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-lifted-base.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lifted-base
version: 0.2.3.12
id: lifted-base-0.2.3.12-Fa7wI9LgVyV52yh4Mgi8Zu
key: lifted-base-0.2.3.12-Fa7wI9LgVyV52yh4Mgi8Zu
license: BSD-3-Clause
copyright: (c) 2011-2012 Bas van Dijk, Anders Kaseorg
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
author: Bas van Dijk, Anders Kaseorg
homepage: https://github.com/basvandijk/lifted-base
synopsis: lifted IO operations from the base library
description:
    @lifted-base@ exports IO operations from the base library lifted to
    any instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.
    .
    Note that not all modules from @base@ are converted yet. If
    you need a lifted version of a function from @base@, just
    ask me to add it or send me a patch.
    .
    The package includes a copy of the @monad-peel@ testsuite written
    by Anders Kaseorg The tests can be performed using @cabal test@.
category: Control
abi: c1af0fff2fd5bc4c8d013de762962125
exposed: True
exposed-modules:
    Control.Concurrent.Chan.Lifted Control.Concurrent.Lifted
    Control.Concurrent.MVar.Lifted Control.Concurrent.QSem.Lifted
    Control.Concurrent.QSemN.Lifted Control.Exception.Lifted
    Data.IORef.Lifted Foreign.Marshal.Utils.Lifted
    System.Timeout.Lifted
import-dirs: /usr/lib/ghc-8.4.3/site-local/lifted-base-0.2.3.12
library-dirs: /usr/lib/ghc-8.4.3/site-local/lifted-base-0.2.3.12
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/lifted-base-0.2.3.12
hs-libraries: HSlifted-base-0.2.3.12-Fa7wI9LgVyV52yh4Mgi8Zu
includes:
    inlinable.h
depends:
    base-4.11.1.0 transformers-base-0.4.5.2-5YBw5fGTiDqHDjkVkrHRIb
    monad-control-1.0.2.3-I3eeoimEMDTINIqXKgCbLk
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             transformers-base-0.4.5.2-5YBw5fGTiDqHDjkVkrHRIb=b60c703c8501b255d99b1477d141017d
             monad-control-1.0.2.3-I3eeoimEMDTINIqXKgCbLk=7b91fe2931b6520a589ebb0da769a2de
haddock-interfaces: /usr/share/doc/haskell-lifted-base/html/lifted-base.haddock
haddock-html: /usr/share/doc/haskell-lifted-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lifted-base-0.2.3.12-17-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-lifted-base.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lifted-base
version: 0.2.3.12
id: lifted-base-0.2.3.12-KjumfQ58uBm8QT3h2l4nDA
key: lifted-base-0.2.3.12-KjumfQ58uBm8QT3h2l4nDA
license: BSD-3-Clause
copyright: (c) 2011-2012 Bas van Dijk, Anders Kaseorg
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
author: Bas van Dijk, Anders Kaseorg
homepage: https://github.com/basvandijk/lifted-base
synopsis: lifted IO operations from the base library
description:
    @lifted-base@ exports IO operations from the base library lifted to
    any instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.
    .
    Note that not all modules from @base@ are converted yet. If
    you need a lifted version of a function from @base@, just
    ask me to add it or send me a patch.
    .
    The package includes a copy of the @monad-peel@ testsuite written
    by Anders Kaseorg The tests can be performed using @cabal test@.
category: Control
abi: bb0bc40b0f20c1d20c198f711f59633a
exposed: True
exposed-modules:
    Control.Concurrent.Chan.Lifted Control.Concurrent.Lifted
    Control.Concurrent.MVar.Lifted Control.Concurrent.QSem.Lifted
    Control.Concurrent.QSemN.Lifted Control.Exception.Lifted
    Data.IORef.Lifted Foreign.Marshal.Utils.Lifted
    System.Timeout.Lifted
import-dirs: /usr/lib/ghc-8.4.3/site-local/lifted-base-0.2.3.12
library-dirs: /usr/lib/ghc-8.4.3/site-local/lifted-base-0.2.3.12
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/lifted-base-0.2.3.12
hs-libraries: HSlifted-base-0.2.3.12-KjumfQ58uBm8QT3h2l4nDA
includes:
    inlinable.h
depends:
    base-4.11.1.0 transformers-base-0.4.5.2-6pRCll7YHiMAUH1nyaFDMy
    monad-control-1.0.2.3-FfEOTMHoA2lIa1PKK0mtSB
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             transformers-base-0.4.5.2-6pRCll7YHiMAUH1nyaFDMy=2dceefd5edb84c5c6b1313f05ee22788
             monad-control-1.0.2.3-FfEOTMHoA2lIa1PKK0mtSB=96aa252ac60feebdbd0ad048336933d6
haddock-interfaces: /usr/share/doc/haskell-lifted-base/html/lifted-base.haddock
haddock-html: /usr/share/doc/haskell-lifted-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
